//
//  CombinedcombinedChartViewController.swift
//  ChartsDemo-OSX
//
//  Copyright 2015 Daniel Cohen Gindi & Philipp Jahoda
//  A port of MPAndroidChart for iOS
//  Licensed under Apache License 2.0
//
//  https://github.com/danielgindi/ios-charts

import Foundation
import Cocoa
import Charts



open class vc14Controller: DemoBaseViewController
{
    @IBOutlet var chartView: HorizontalBarChartView!
    
    @IBOutlet var mainMenu: NSMenu!
    
    @IBOutlet weak var sliderX: NSSlider!
    @IBOutlet weak var sliderY: NSSlider!
    
    @IBOutlet weak var sliderTextX: NSTextField!
    @IBOutlet weak var sliderTextY: NSTextField!
    
    override open func viewDidAppear()
    {
        super.viewDidAppear()
        view.window!.title = "Horizontal Bar Chart"
    }
    
    override open func viewDidLoad()
    {
        super.viewDidLoad()
        
        let options = [["label": "Zoom In"],
                       ["label": "Zoom out"],
                       ["label": "Reset Zoom"],
                       ["label": "separator"],
                       ["label": "Toggle Values"],
                       ["label": "Toggle Highlight"],
                       ["label": "Animate X"],
                       ["label": "Animate Y"],
                       ["label": "Animate XY"],
                       ["label": "Save to Camera Roll"],
                       ["label": "Toggle PinchZoom"],
                       ["label": "Toggle auto scale min/max"],
                       ["label": "Toggle Data"]]
        
        mainMenu.removeAllItems()
        for option in options
        {
            if option["label"]  == "separator"
            {
                mainMenu.addItem(NSMenuItem.separator())
            }
            else
            {
                mainMenu.addItem(withTitle: option["label"]!, action: #selector(vc14Controller.optionTapped(sender:)), keyEquivalent: "")
            }
       }
        for item: AnyObject in mainMenu.items {
            if let menuItem = item as? NSMenuItem {
                menuItem.target = self
            }
        }
        
        // General                                         -->     1
        chartView.drawBarShadowEnabled = false
        chartView.drawValueAboveBarEnabled = true
        chartView.maxVisibleCount = 60
        chartView.chartDescription?.text = "Horizontal Bar Chart"
        chartView.fitBars = true
        
        // xAxis                                           -->      2
        let xAxis = chartView.xAxis
        xAxis.labelPosition = .bottom
        xAxis.labelFont = NSUIFont.systemFont(ofSize: CGFloat(10.0))
        xAxis.drawAxisLineEnabled = true
        xAxis.drawGridLinesEnabled = false
        xAxis.granularity = 10.0
        
        // leftAxis                                         -->      3
        let leftAxis = chartView.leftAxis
        leftAxis.labelFont = NSUIFont.systemFont(ofSize: CGFloat(10.0))
        leftAxis.drawAxisLineEnabled = true
        leftAxis.drawGridLinesEnabled = true
        leftAxis.axisMinimum = 0.0
        
        // rightAxis                                        -->      4
        let rightAxis                  = chartView.rightAxis
        rightAxis.enabled              = true
        rightAxis.labelFont            = NSUIFont.systemFont(ofSize: CGFloat(10.0))
        rightAxis.drawAxisLineEnabled  = true
        rightAxis.drawGridLinesEnabled = false
        rightAxis.axisMinimum          = 0.0
        
        // legend                                           -->      5
        let l = chartView.legend
        l.horizontalAlignment = .left
        l.verticalAlignment = .bottom
        l.orientation = .horizontal
        l.drawInside = false
        l.form = .square
        l.formSize = 8.0
        l.font = NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(11.0))!
        l.xEntrySpace = 4.0
        
        sliderX.doubleValue = 12.0
        sliderY.doubleValue = 50.0
        slidersValueChanged(sliderX)
        chartView.animate(xAxisDuration: 2.5)
    }
    
    func updateChartData()
    {
        setDataCount(Int(sliderX.intValue) + 1, range: sliderY.doubleValue)
    }
    
    func setDataCount(_ count: Int, range: Double)
    {
        let barWidth = 9.0
        let spaceForBar = 10.0
        
        // BarChartDataEntry                                -->      6
        var yVals = [BarChartDataEntry]()
        for i in 0..<count
        {
            let mult = range + 1.0
            let val = Double(arc4random_uniform(UInt32(mult)))
            yVals.append(BarChartDataEntry(x: Double(i) * spaceForBar, y: val))
        }
        
        // BarChartDataSet                                  -->      7
        var set1 = BarChartDataSet()
        if chartView.data != nil
        {
            set1 = ( chartView.data?.dataSets[0] as? BarChartDataSet)!
            set1.values = yVals
            chartView.data?.notifyDataChanged()
            chartView.notifyDataSetChanged()
        }
        else
        {
            set1                = BarChartDataSet(values: yVals, label: "DataSet")

            // BarChartData                                 -->      8
            let data            = BarChartData(dataSets: [set1])
            data.setValueFont(NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(10.0)))
            data.barWidth       = barWidth
            chartView.data = data
        }
    }
    
    func optionTapped( sender: NSMenuItem)
    {
        switch (sender.title)
        {
        default:
            super.toggle(sender.title, chartView: chartView)
        }
    }
    
    @IBAction func slidersValueChanged(_ sender: AnyObject)
    {
        sliderTextX.stringValue = String(Int( sliderX.intValue))
        sliderTextY.stringValue = String(Int( sliderY.intValue))
        updateChartData()
    }
}


